==> cejs-4.5.1.tgz: package/application/locale/resources/guw-BJ.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"\u2191Back to TOC": "\u2191L\u1eb9k\u1ecdyi TOC",
	"expand": "Dl\u1eb9n",
	"number": "S\u1ecdha",
	"function": "Y\u1ecdn-na yizan",
	"Language": "Ogb\u00e8",
	"no change": "Di\u1ecddo matin",
	"No changes.": "Di\u1ecddo de matin",
	"Abandon change": "W\u1ecdny\u00e0na di\u1ecddo",
	"No reason provided": "Wh\u1eb9whinwh\u1eb9n depope ma yin nina",
	"%1 Y": "%1 Y",
	"%1 min": "%1 nuk",
	"now": "Din",
	"soon": "mad\u1eb9nm\u1eb9",
	"%1 minutes ago": "%1 nukunwhiwhe del\u1eb9 die",
	"%1 minutes later": "%1 nukunwhiwhe del\u1eb9 godo",
	"%1 hours ago": "%1 ganhiho del\u1eb9 die",
	"%1 hours later": "%1 ganhiho l\u1eb9 godo",
	"yesterday, %H:%M": "\u1eccs\u1ecd he wayi, %H:%M",
	"today, %H:%M": "Egb\u00e9, %H:%M",
	"tomorrow, %H:%M": "os\u1ecd he ja, %H:%M",
	"the day after tomorrow, %H:%M": "Az\u00e1n at\u1ecd\u0300n gb\u00e8, %H:%M",
	"3 days after tomorrow, %H:%M": "Az\u00e1n \u1eb9n\u1eb9 gbe, %H:%M",
	"%1 days ago": "%1 az\u00e1n del\u1eb9 die",
	"%1 days later": "%1 az\u00e1n l\u1eb9 godo",
	"%1 weeks later": "%1 \u1ecds\u1eb9 l\u1eb9 godo",
	"\u8df3\u904e [%1]\uff1a\u672c[%2]\u50c5\u4f9b\u53c3\u7167\u7528\u3002": "Das\u00e1 [%1]: %2 l\u1ecd tin na l\u1eb9ndai al\u1ecddl\u1eb9ndonu t\u1ecdn k\u1eb9d\u1eb9.",
	"\u4e2d\u570b": "China",
	"\u65e5\u672c": "Japan",
	"\u7409\u7403": "Ryukyu",
	"\u0e2d\u0e32\u0e13\u0e32\u0e08\u0e31\u0e01\u0e23\u0e2a\u0e38\u0e42\u0e02\u0e17\u0e31\u0e22": "Ah\u1ecdluduta Sukhothai t\u1ecdn",
	"India": "India",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "Myanmar",
	"Pagan": "Kosi",
	"Toungoo": "Toungoo",
	"\u1000\u102f\u1014\u103a\u1038\u1018\u1031\u102c\u1004\u103a\u1001\u1031\u1010\u103a": "Konbaung",
	"Maya": "Maya",
	"Babylon": "Babil\u1ecdni",
	"Persia": "P\u1eb9lsia",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "Sparta",
	"Hittite": "Hitinu",
	"\u6e2c\u8a66\u7bc4\u4f8b": "APAJL\u1eb8",
	"\u5171\u6709 %1 \u500b\u5e74\u6bb5\u7d00\u9304": "%1 owhe l\u1eb9",
	"%1 CE": "%1 CE",
	"\u63a1\u7528\u66c6\u6cd5": "Sunzanhiawe he yin zinzan",
	"\u541b\u4e3b\u540d": "Yink\u1ecd m\u1eb9detiti t\u1ecdn",
	"\u901d\u4e16": "Ko K\u00fa",
	"\u7236\u89aa": "Ot\u1ecd\u0301",
	"\u6bcd\u89aa": "\u00d2n\u1ecd",
	"\u5168\u4e0d\u9078": "De POPO L\u1eb8PO s\u1eb9",
	"\u5206\u985e": "Ogb\u1eb9\u0301",
	"Gregorian calendar": "S\u00f9nz\u00e1nhiawe Gregorian t\u1ecdn",
	"Julian calendar": "Sunzanhiawe Julia t\u1ecdn",
	"JD": "JD",
	"JDN": "JDN",
	"Julian Day Number": "S\u1ecdha Azan Julian T\u1ecdn",
	"Holocene calendar": "S\u00f9nz\u00e1nhiawe Holocene t\u1ecdn",
	"\u6714": "osun y\u1ecdy\u1ecd",
	"\u65e5\u51fa\u65e5\u843d": "af\u1ecdnnu / whejai",
	"sunrise": "Af\u1ecdnnu",
	"\u4f0a\u65af\u862d\u66c6": "S\u00f9nz\u00e1nhiawe Mal\u00e9nu t\u1ecdn",
	"\u5e0c\u4f2f\u4f86\u66c6": "S\u00f9nz\u00e1nhiawe Heblu t\u1ecdn",
	"\u1019\u103c\u1014\u103a\u1019\u102c \u1015\u103c\u1000\u1039\u1001\u1012\u102d\u1014\u103a": "S\u00f9nz\u00e1nhiawe Myanmar t\u1ecdn",
	"\u0939\u093f\u0928\u094d\u0926\u0942 \u092a\u0902\u091a\u093e\u0902\u0917": "Sunzanhiawe Hindu l\u1eb9 t\u1ecdn",
	"\u53e4\u57c3\u53ca\u66c6": "Sunzanhiawe Egipti t\u1ecdn",
	"Taurus": "Taulusi",
	"Leo": "Leo",
	"Libra": "Libra",
	"\u9ec3\u5e1d\u7d00\u5143": "Huangdi",
	"Italy": "Itali",
	"Espa\u00f1a": "Espa\u00f1a",
	"Portugal": "P\u1ecdtuga",
	"Poland": "Poland",
	"Luxembourg": "Luxembourg",
	"Netherlands": "Netherlands",
	"Bavaria": "Bavaria",
	"Austria": "Austria",
	"Switzerland": "Switzerland",
	"Hungary": "Hungary",
	"Norway": "Norway",
	"Denmark": "Denmark",
	"Sweden": "Sweden",
	"Finland": "Finland",
	"Soviet Union": "Soviet Union",
	"Serbia": "Sabia",
	"Greece": "Gliki",
	"Egypt": "Egipti",
	"\u516c\u5143": "Wh\u00e8 M\u00edt\u1ecdn",
	"\u6240\u6709\u570b\u5bb6": "Ot\u00f2 l\u1eb9po",
	"\u541b\u4e3b\u751f\u5352": "Gb\u1eb9wh\u1eb9nu g\u00e1ndut\u1ecd l\u1eb9 t\u1ecdn",
	"untranslated message count": "960"
},
"guw-BJ");

==> cejs-4.5.2.tgz: package/application/locale/resources/guw-BJ.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"untranslated message count": "1000+",
	"Espa\u00f1a": "Espa\u00f1a",
	"\u541b\u4e3b\u751f\u5352": "Gb\u1eb9wh\u1eb9nu g\u00e1ndut\u1ecd l\u1eb9 t\u1ecdn",
	"\u6240\u6709\u570b\u5bb6": "Ot\u00f2 l\u1eb9po",
	"\u6e2c\u8a66\u7bc4\u4f8b": "APAJL\u1eb8",
	"Julian Day Number": "S\u1ecdha Azan Julian T\u1ecdn",
	"\u63a1\u7528\u66c6\u6cd5": "Sunzanhiawe he yin zinzan",
	"\u541b\u4e3b\u540d": "Yink\u1ecd m\u1eb9detiti t\u1ecdn",
	"\u901d\u4e16": "Ko K\u00fa",
	"\u516c\u5143": "Wh\u00e8 M\u00edt\u1ecdn",
	"\u7236\u89aa": "Ot\u1ecd\u0301",
	"\u6bcd\u89aa": "\u00d2n\u1ecd",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "Myanmar",
	"Taurus": "Taulusi",
	"Leo": "Leo",
	"Libra": "Libra",
	"JDN": "JDN",
	"JD": "JD",
	"\u6714": "osun y\u1ecdy\u1ecd",
	"\u65e5\u51fa\u65e5\u843d": "af\u1ecdnnu / whejai",
	"Gregorian calendar": "S\u00f9nz\u00e1nhiawe Gregorian t\u1ecdn",
	"Julian calendar": "Sunzanhiawe Julia t\u1ecdn",
	"\u4f0a\u65af\u862d\u66c6": "S\u00f9nz\u00e1nhiawe Mal\u00e9nu t\u1ecdn",
	"\u5e0c\u4f2f\u4f86\u66c6": "S\u00f9nz\u00e1nhiawe Heblu t\u1ecdn",
	"\u5206\u985e": "Ogb\u1eb9\u0301",
	"\u1019\u103c\u1014\u103a\u1019\u102c \u1015\u103c\u1000\u1039\u1001\u1012\u102d\u1014\u103a": "S\u00f9nz\u00e1nhiawe Myanmar t\u1ecdn",
	"\u0939\u093f\u0928\u094d\u0926\u0942 \u092a\u0902\u091a\u093e\u0902\u0917": "Sunzanhiawe Hindu l\u1eb9 t\u1ecdn",
	"\u53e4\u57c3\u53ca\u66c6": "Sunzanhiawe Egipti t\u1ecdn",
	"\u4e2d\u570b": "China",
	"\u9ec3\u5e1d\u7d00\u5143": "Huangdi",
	"Holocene calendar": "S\u00f9nz\u00e1nhiawe Holocene t\u1ecdn",
	"%1 CE": "%1 CE",
	"\u5171\u6709 %1 \u500b\u5e74\u6bb5\u7d00\u9304": "%1 owhe l\u1eb9",
	"\u5168\u4e0d\u9078": "De POPO L\u1eb8PO s\u1eb9",
	"No changes.": "Di\u1ecddo de matin",
	"sunrise": "Af\u1ecdnnu",
	"Language": "Ogb\u00e8",
	"Abandon change": "W\u1ecdny\u00e0na di\u1ecddo",
	"No reason provided": "Wh\u1eb9whinwh\u1eb9n depope ma yin nina",
	"no change": "Di\u1ecddo matin",
	"function": "Y\u1ecdn-na yizan",
	"number": "S\u1ecdha",
	"Italy": "Itali",
	"Poland": "Poland",
	"Portugal": "P\u1ecdtuga",
	"Luxembourg": "Luxembourg",
	"Netherlands": "Netherlands",
	"Bavaria": "Bavaria",
	"Austria": "Austria",
	"Switzerland": "Switzerland",
	"Hungary": "Hungary",
	"Norway": "Norway",
	"Denmark": "Denmark",
	"Sweden": "Sweden",
	"Finland": "Finland",
	"Soviet Union": "Soviet Union",
	"Serbia": "Sabia",
	"Greece": "Gliki",
	"Egypt": "Egipti",
	"%1 Y": "%1 Y",
	"%1 min": "%1 nuk",
	"yesterday, %H:%M": "\u1eccs\u1ecd he wayi, %H:%M",
	"today, %H:%M": "Egb\u00e9, %H:%M",
	"tomorrow, %H:%M": "os\u1ecd he ja, %H:%M",
	"the day after tomorrow, %H:%M": "Az\u00e1n at\u1ecd\u0300n gb\u00e8, %H:%M",
	"3 days after tomorrow, %H:%M": "Az\u00e1n \u1eb9n\u1eb9 gbe, %H:%M",
	"now": "Din",
	"soon": "mad\u1eb9nm\u1eb9",
	"%1 {{PLURAL:%1|minute|minutes}} ago": "%1 nukunwhiwhe del\u1eb9 die",
	"%1 {{PLURAL:%1|minute|minutes}} later": "%1 nukunwhiwhe del\u1eb9 godo",
	"%1 {{PLURAL:%1|hour|hours}} ago": "%1 ganhiho del\u1eb9 die",
	"%1 {{PLURAL:%1|hour|hours}} later": "%1 ganhiho l\u1eb9 godo",
	"%1 {{PLURAL:%1|day|days}} ago": "%1 az\u00e1n del\u1eb9 die",
	"%1 {{PLURAL:%1|day|days}} later": "%1 az\u00e1n l\u1eb9 godo",
	"%1 {PLURAL:%1|week|weeks}} later": "%1 \u1ecds\u1eb9 l\u1eb9 godo",
	"\u8df3\u904e [%1]\uff1a\u672c[%2]\u50c5\u4f9b\u53c3\u7167\u7528\u3002": "Das\u00e1 [%1]: %2 l\u1ecd tin na l\u1eb9ndai al\u1ecddl\u1eb9ndonu t\u1ecdn k\u1eb9d\u1eb9.",
	"\u7409\u7403": "Ryukyu",
	"\u65e5\u672c": "Japan",
	"\u0e2d\u0e32\u0e13\u0e32\u0e08\u0e31\u0e01\u0e23\u0e2a\u0e38\u0e42\u0e02\u0e17\u0e31\u0e22": "Ah\u1ecdluduta Sukhothai t\u1ecdn",
	"Pagan": "Kosi",
	"Toungoo": "Toungoo",
	"\u1000\u102f\u1014\u103a\u1038\u1018\u1031\u102c\u1004\u103a\u1001\u1031\u1010\u103a": "Konbaung",
	"India": "India",
	"Babylon": "Babil\u1ecdni",
	"Persia": "P\u1eb9lsia",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "Sparta",
	"Hittite": "Hitinu",
	"Maya": "Maya",
	"\u2191Back to TOC": "\u2191L\u1eb9k\u1ecdyi TOC",
	"expand": "Dl\u1eb9n"
},
"guw-BJ");
